# Generated by Django 5.1.1 on 2024-09-19 22:01

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Channel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('status', models.BooleanField(default=True)),
                ('name', models.CharField(max_length=255, unique=True)),
                ('slug', models.SlugField(blank=True, max_length=255, unique=True)),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 5.1.1 on 2024-09-20 17:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('channels', '0005_customerchannel'),
    ]

    operations = [
        migrations.AddField(
            model_name='customerchannel',
            name='order',
            field=models.PositiveSmallIntegerField(default=1),
            preserve_default=False,
        ),
    ]



"""
ASGI config for comunication_channels project.

It exposes the ASGI callable as a module-level variable named ``application``.

For more information on this file, see
https://docs.djangoproject.com/en/5.1/howto/deployment/asgi/
"""

import os

from django.core.asgi import get_asgi_application

os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'comunication_channels.settings')

application = get_asgi_application()



from django.db.models.signals import post_migrate
from django.dispatch import receiver




@receiver(post_migrate)
def execute_after_migrations(sender, **kwargs):
    from artd_modules.utils import create_or_update_module_row


    create_or_update_module_row(
        slug="artd_channel",
        name="ArtD Channels",
        description="ArtD Channels",
        version="1.0.3",
        is_plugin=False,
    )



from django.core.management.base import BaseCommand
from channels.models import Provider
from django.utils.text import slugify

class Command(BaseCommand):
    help = 'Populate the Channel model with WhatsApp, SMS, and Email'

    def handle(self, *args, **kwargs):
        providers = [
            {
             'name': 'Aws',
             'id':1
            },
            {
             'name': 'Messagebird',
             'id':2
            },
        ]

        for providers_data in providers:
            name = providers_data['name']
            slug = slugify(name)
            id = providers_data['id']
            
            # Verificar si ya existe un canal con el mismo slug o nombre
            provider, created = Provider.objects.update_or_create(
                id = id,
                defaults={
                    'name': name,
                    'slug': slug,

                }
        
            )
            
            if created:
                self.stdout.write(self.style.SUCCESS(f'Provider {name} created successfully.'))
            else:
                self.stdout.write(self.style.WARNING(f'Provider {name} already exists.'))
